import { Handlers, PageProps } from "$fresh/server.ts";
import { MainLayout } from "@components/layouts/main.tsx";
import IconArrowLeft from "https://deno.land/x/tabler_icons_tsx@0.0.3/tsx/arrow-left.tsx";
import { getAllMovies, Movie } from "@lib/resource/movies.ts";
import { MovieCard } from "@components/MovieCard.tsx";

export const handler: Handlers<Movie[] | null> = {
  async GET(_, ctx) {
    const movies = await getAllMovies();
    return ctx.render(movies);
  },
};

export default function Greet(props: PageProps<Movie[] | null>) {
  return (
    <MainLayout url={props.url}>
      <header class="flex gap-4 items-center mb-5 md:hidden">
        <a
          class="px-4 ml-4 py-2 bg-gray-300 text-gray-800 rounded-lg flex items-center gap-1"
          href="/"
        >
          <IconArrowLeft class="w-5 h-5" />
          Back
        </a>

        <h3 class="text-2xl text-white font-light">🍿 Movies</h3>
      </header>
      <div class="flex flex-wrap items-center gap-4 px-4">
        {props.data?.map((doc) => {
          return <MovieCard movie={doc} />;
        })}
      </div>
    </MainLayout>
  );
}
