import { Handlers, PageProps } from "$fresh/server.ts";
import { RecipeCard } from "@components/RecipeCard.tsx";
import { MainLayout } from "@components/layouts/main.tsx";
import { getAllRecipes, Recipe } from "@lib/resource/recipes.ts";
import IconArrowLeft from "https://deno.land/x/tabler_icons_tsx@0.0.3/tsx/arrow-left.tsx";

export const handler: Handlers<Recipe[] | null> = {
  async GET(_, ctx) {
    const recipes = await getAllRecipes();
    return ctx.render(recipes);
  },
};

export default function Greet(props: PageProps<Recipe[] | null>) {
  return (
    <MainLayout url={props.url}>
      <header class="flex gap-4 items-center mb-5 md:hidden">
        <a
          class="px-4 ml-4 py-2 bg-gray-300 text-gray-800 rounded-lg flex items-center gap-1"
          href="/"
        >
          <IconArrowLeft class="w-5 h-5" />
          Back
        </a>

        <h3 class="text-2xl text-white font-light">🍽️ Recipes</h3>
      </header>
      <div class="flex flex-wrap items-center gap-4 px-4">
        {props.data?.map((doc) => {
          return <RecipeCard recipe={doc} />;
        })}
      </div>
    </MainLayout>
  );
}
